==> k8048-1.00.tar.gz: k8048/k8048/pic16f.h <==
/*
 * Velleman K8048 Programmer for FreeBSD and others.
 *
 * Copyright (c) 2005-2007 Darron Broad
 * All rights reserved.
 *
 * Licensed under the terms of the BSD license, see file LICENSE
 * for details.
 *
 * $Id: pic16f.h,v 1.53 2008/02/20 04:32:50 darron Exp $
 */

#ifndef _PIC16F_H
#define _PIC16F_H

/* pic16f configuration */
#define PIC16F_CONFIG_USERID0   (0)
#define PIC16F_CONFIG_USERID1   (1)
#define PIC16F_CONFIG_USERID2   (2)
#define PIC16F_CONFIG_USERID3   (3)
#define PIC16F_CONFIG_DEVICEID  (6)
#define PIC16F_CONFIG_WORD1     (7)
#define PIC16F_CONFIG_WORD2     (8) /* F88, F688 (OSCCAL) */
#define PIC16F_CONFIG_WORD3     (9) /*      F688 (OSCCAL) */
#define PIC16F_CONFIG_SIZE      (10)
struct pic16f_config {
    unsigned short index[PIC16F_CONFIG_SIZE];
};

/*
 * deviceid and revision mask
 *
 * nb. the actual deviceid is (0x2006)>>5
 */
#define PIC16F_DEVICEID_MASK  (0x3FE0)
#define PIC16F_DEVICEREV_MASK (0x001F)

/*
 * DS30262E
 * PIC16F84A 00 0101 011X XXXX
 */
#define DS30262E        (30262)
#define PIC16F84A       (0x0560)

#define PIC16F84        (0x0560) /* ? */
#define PIC16C84        (0x0560)

/*
 * DS30277D PAGE 3-161
 *  PIC16F627 00 0111 101X XXXX
 *  PIC16F627 00 0111 110X XXXX
 */
#define DS30277D    (30277)
#define PIC16F627   (0x07a0)
#define PIC16F628   (0x07c0)

/*
 * DS39025F
 *  PIC16F870 00 1101 000X XXXX
 *  PIC16F871 00 1101 001X XXXX
 *  PIC16F872 00 1100 111X XXXX
 *  PIC16F873 00 1001 011X XXXX
 *  PIC16F874 00 1001 001X XXXX
 *  PIC16F876 00 1001 111X XXXX
 *  PIC16F877 00 1001 101X XXXX
 */
#define DS39025F    (39025)
#define PIC16F870   (0x0d00)
#define PIC16F871   (0x0d20)
#define PIC16F872   (0x0ce0)
#define PIC16F873   (0x0960)
#define PIC16F874   (0x0920)
#define PIC16F876   (0x09e0)
#define PIC16F877   (0x09a0)

/*
 * DS39589B
 *  PIC16F873A 00 1110 0100 XXXX
 *  PIC16F874A 00 1110 0110 XXXX
 *  PIC16F876A 00 1110 0000 XXXX
 *  PIC16F877A 00 1110 0010 XXXX
 */
#define DS39589B    (39589)
#define PIC16F873A  (0x0e40)
#define PIC16F874A  (0x0e60)
#define PIC16F876A  (0x0e00)
#define PIC16F877A  (0x0e20)

/*
 * DS39607B
 *  PIC16F87 00 0111 0010 XXXX
 *  PIC16F88 00 0111 0110 XXXX
 */
#define DS39607B    (39607)
#define PIC16F87    (0x0720)
#define PIC16F88    (0x0760)

/*
 * DS41191C
 *  PIC12F629 00 1111 100X XXXX
 *  PIC12F675 00 1111 110X XXXX
 *  PIC16F630 01 0000 110X XXXX
 *  PIC16F676 01 0000 111X XXXX
 */
#define DS41191C    (41191)
#define PIC12F629   (0x0f80)
#define PIC12F675   (0x0fc0)
#define PIC16F630   (0x10c0)
#define PIC16F676   (0x10e0)

/*
 * DS41196F
 *  PIC16F627A 01 0000 010X XXXX
 *  PIC16F628A 01 0000 011X XXXX
 *  PIC16F648A 01 0001 000X XXXX
 */
#define DS41196F   (41196)
#define PIC16F627A (0x1040)
#define PIC16F628A (0x1060)
#define PIC16F648A (0x1100)

/*
 * DS39603C
 *  PIC16F818 00 0100 1100 XXXX
 *  PIC16F819 00 0100 1110 XXXX
 */
#define DS39603C    (39603)
#define PIC16F818   (0x04c0)
#define PIC16F819   (0x04e0)

/*
 * DS40245B
 *  PIC16F716 01 0001 010X XXXX
 */
#define DS40245B    (40245)
#define PIC16F716   (0x1140)

/*
 * DS41204G
 *  PIC12F635 00 1111 101X XXXX
 *  PIC12F683 00 0100 011X XXXX
 *  PIC16F631 01 0100 001X XXXX
 *  PIC16F636 01 0000 101X XXXX XXX
 *  PIC16F639 01 0000 101X XXXX XXX
 *  PIC16F677 01 0100 010X XXXX
 *  PIC16F684 01 0000 100X XXXX
 *  PIC16F685 00 0100 101X XXXX
 *  PIC16F688 01 0001 100X XXXX
 *  PIC16F689 01 0011 010X XXXX
 *  PIC16F690 01 0100 000X XXXX
 */
#define DS41204G  (41204)
#define PIC12F635 (0x0fa0)
#define PIC12F683 (0x0460)
#define PIC16F631 (0x1420)
#define PIC16F636 (0x10a0)
#define PIC16F639 (0x10a0)
#define PIC16F677 (0x1440)
#define PIC16F684 (0x1080)
#define PIC16F685 (0x04a0)
#define PIC16F688 (0x1180)
#define PIC16F689 (0x1340)
#define PIC16F690 (0x1400)

/* device to datasheet map */
struct pic16f_dsmap
{
    char devicename[STRLEN];
    unsigned short deviceid;
    unsigned int datasheet;
    unsigned short osccaladdr;
    unsigned short configmask;
#if 0
    unsigned char tprog, terase;
#endif
};

/* regions (program/data/config) */
#define PIC16F_REGIONUNKNOWN  (0)
#define PIC16F_REGIONCODE     (1)
#define PIC16F_REGIONCONFIG   (2)
#define PIC16F_REGIONDATA     (3)

/* device memory map */
#define PIC16F_CODE_LOW    (0x0000)
#define PIC16F_CODE_HIGH   (0x1fff)
#define PIC16F_CONFIG_LOW  (0x2000)
#define PIC16F_CONFIG_HIGH (0x20ff)
#define PIC16F_DATA_LOW    (0x2100)
#define PIC16F_DATA_HIGH   (0x21ff)

/* default timings until per datasheet */
#define PIC16F_TPROG_DEFAULT (10000)        /* 10ms */
#define PIC16F_TERASE_DEFAULT (10000)       /* 10ms */
#define PIC16F_TDISCHARGE_DEFAULT (1000)   /*  1ms */

/* FIXME hardware function prototypes */
#if 0
void            pic16f_begin_programming_(struct k8048 *);
void            pic16f_begin_programming_(struct k8048 *);
void            pic16f_end_programming_(struct k8048 *);
void            pic16f_end_programming_(struct k8048 *);
#endif
void            pic16f_load_configuration(struct k8048 *, unsigned short);
void            pic16f_load_data_for_program_memory(struct k8048 *, unsigned short);
void            pic16f_load_data_for_data_memory(struct k8048 *, unsigned short);
void            pic16f_increment_address(struct k8048 *);
unsigned short  pic16f_read_data_from_program_memory(struct k8048 *);
unsigned char   pic16f_read_data_from_data_memory(struct k8048 *);
void            pic16f_begin_erase_programming(struct k8048 *);
void            pic16f_chip_erase(struct k8048 *);
void            pic16f_bulk_erase_program_memory(struct k8048 *);
void            pic16f_bulk_erase_data_memory(struct k8048 *);
void            pic16f_bulk_erase_setup1(struct k8048 *);
void            pic16f_bulk_erase_setup2(struct k8048 *);

/* compound functions */
unsigned short pic16f_read_program_memory_increment(struct k8048 *);
unsigned char  pic16f_read_data_memory_increment(struct k8048 *);
void pic16f_read_config_memory(struct k8048 *);
unsigned short pic16f_read_osccal(struct k8048 *);
unsigned short pic16f_read_program_memory_block(struct k8048 *, unsigned short *, int);
unsigned short pic16f_read_data_memory_block(struct k8048 *, unsigned char *, int);
void pic16f_disableprotection(struct k8048 *, unsigned short osccal, unsigned short config);
void pic16f_bulkerase(struct k8048 *);
int pic16f_write_osccal(struct k8048 *, unsigned short);
int pic16f_write_config(struct k8048 *, unsigned short);

/* regions (code/config/data) */
int pic16f_getregion(unsigned int);
unsigned int pic16f_initregion(struct k8048 *, int);
void pic16f_loadregion(struct k8048 *, int, unsigned short);
int pic16f_verifyregion(struct k8048 *, unsigned short, unsigned short, int);

/* program/verify */
void pic16f_programregion(struct k8048 *, unsigned short, int, unsigned short);
void pic16f_program(struct k8048 *);
int pic16f_verify(struct k8048 *);

/* diagnostics */
void pic16f_dumpdeviceid(struct k8048 *);
void pic16f_dumposccal(struct k8048 *);
void pic16f_dumpconfig(struct k8048 *);
void pic16f_dumpconfig_16f627(unsigned int);
void pic16f_dumpconfig_12f675(unsigned int);
void pic16f_dumpconfig_16f877a(unsigned int);
void pic16f_dumpconfig_16f88(unsigned int, unsigned int);

#endif

==> k8048-1.04.tar.gz: k8048/k8048/pic16f.h <==
/*
 * Velleman K8048 Programmer for FreeBSD and others.
 *
 * Copyright (c) 2005-2007 Darron Broad
 * All rights reserved.
 *
 * Licensed under the terms of the BSD license, see file LICENSE
 * for details.
 *
 * $Id: pic16f.h,v 1.54 2008/09/19 04:07:02 darron Exp $
 */

#ifndef _PIC16F_H
#define _PIC16F_H

/* pic16f configuration */
#define PIC16F_CONFIG_USERID0   (0)
#define PIC16F_CONFIG_USERID1   (1)
#define PIC16F_CONFIG_USERID2   (2)
#define PIC16F_CONFIG_USERID3   (3)
#define PIC16F_CONFIG_DEVICEID  (6)
#define PIC16F_CONFIG_WORD1     (7)
#define PIC16F_CONFIG_WORD2     (8) /* F88, F688 (OSCCAL) */
#define PIC16F_CONFIG_WORD3     (9) /*      F688 (OSCCAL) */
#define PIC16F_CONFIG_SIZE      (10)
struct pic16f_config {
    unsigned short index[PIC16F_CONFIG_SIZE];
};

/*
 * deviceid and revision mask
 *
 * nb. the actual deviceid is (0x2006)>>5
 */
#define PIC16F_DEVICEID_MASK  (0x3FE0)
#define PIC16F_DEVICEREV_MASK (0x001F)

/*
 * DS30262E
 * PIC16F84A 00 0101 011X XXXX
 */
#define DS30262E        (30262)
#define PIC16F84A       (0x0560)

#define PIC16F84        (0x0560) /* ? */
#define PIC16C84        (0x0560)

/*
 * DS30277D PAGE 3-161
 *  PIC16F627 00 0111 101X XXXX
 *  PIC16F627 00 0111 110X XXXX
 */
#define DS30277D    (30277)
#define PIC16F627   (0x07a0)
#define PIC16F628   (0x07c0)

/*
 * DS39025F
 *  PIC16F870 00 1101 000X XXXX
 *  PIC16F871 00 1101 001X XXXX
 *  PIC16F872 00 1100 111X XXXX
 *  PIC16F873 00 1001 011X XXXX
 *  PIC16F874 00 1001 001X XXXX
 *  PIC16F876 00 1001 111X XXXX
 *  PIC16F877 00 1001 101X XXXX
 */
#define DS39025F    (39025)
#define PIC16F870   (0x0d00)
#define PIC16F871   (0x0d20)
#define PIC16F872   (0x0ce0)
#define PIC16F873   (0x0960)
#define PIC16F874   (0x0920)
#define PIC16F876   (0x09e0)
#define PIC16F877   (0x09a0)

/*
 * DS39589B
 *  PIC16F873A 00 1110 0100 XXXX
 *  PIC16F874A 00 1110 0110 XXXX
 *  PIC16F876A 00 1110 0000 XXXX
 *  PIC16F877A 00 1110 0010 XXXX
 */
#define DS39589B    (39589)
#define PIC16F873A  (0x0e40)
#define PIC16F874A  (0x0e60)
#define PIC16F876A  (0x0e00)
#define PIC16F877A  (0x0e20)

/*
 * DS39607B
 *  PIC16F87 00 0111 0010 XXXX
 *  PIC16F88 00 0111 0110 XXXX
 */
#define DS39607B    (39607)
#define PIC16F87    (0x0720)
#define PIC16F88    (0x0760)

/*
 * DS41191C
 *  PIC12F629 00 1111 100X XXXX
 *  PIC12F675 00 1111 110X XXXX
 *  PIC16F630 01 0000 110X XXXX
 *  PIC16F676 01 0000 111X XXXX
 */
#define DS41191C    (41191)
#define PIC12F629   (0x0f80)
#define PIC12F675   (0x0fc0)
#define PIC16F630   (0x10c0)
#define PIC16F676   (0x10e0)

/*
 * DS41196F
 *  PIC16F627A 01 0000 010X XXXX
 *  PIC16F628A 01 0000 011X XXXX
 *  PIC16F648A 01 0001 000X XXXX
 */
#define DS41196F   (41196)
#define PIC16F627A (0x1040)
#define PIC16F628A (0x1060)
#define PIC16F648A (0x1100)

/*
 * DS39603C
 *  PIC16F818 00 0100 1100 XXXX
 *  PIC16F819 00 0100 1110 XXXX
 */
#define DS39603C    (39603)
#define PIC16F818   (0x04c0)
#define PIC16F819   (0x04e0)

/*
 * DS40245B
 *  PIC16F716 01 0001 010X XXXX
 */
#define DS40245B    (40245)
#define PIC16F716   (0x1140)

/*
 * DS41204G
 *  PIC12F635 00 1111 101X XXXX
 *  PIC12F683 00 0100 011X XXXX
 *  PIC16F631 01 0100 001X XXXX
 *  PIC16F636 01 0000 101X XXXX XXX
 *  PIC16F639 01 0000 101X XXXX XXX
 *  PIC16F677 01 0100 010X XXXX
 *  PIC16F684 01 0000 100X XXXX
 *  PIC16F685 00 0100 101X XXXX
 *  PIC16F688 01 0001 100X XXXX
 *  PIC16F689 01 0011 010X XXXX
 *  PIC16F690 01 0100 000X XXXX
 */
#define DS41204G  (41204)
#define PIC12F635 (0x0fa0)
#define PIC12F683 (0x0460)
#define PIC16F631 (0x1420)
#define PIC16F636 (0x10a0)
#define PIC16F639 (0x10a0)
#define PIC16F677 (0x1440)
#define PIC16F684 (0x1080)
#define PIC16F685 (0x04a0)
#define PIC16F688 (0x1180)
#define PIC16F689 (0x1340)
#define PIC16F690 (0x1400)

/* device to datasheet map */
struct pic16f_dsmap
{
    char devicename[STRLEN];
    unsigned short deviceid;
    unsigned int datasheet;
    unsigned short osccaladdr;
    unsigned short configmask;
#if 0
    unsigned char tprog, terase;
#endif
};

/* regions (program/data/config) */
#define PIC16F_REGIONUNKNOWN  (0)
#define PIC16F_REGIONCODE     (1)
#define PIC16F_REGIONCONFIG   (2)
#define PIC16F_REGIONDATA     (3)

/* device memory map */
#define PIC16F_CODE_LOW    (0x0000)
#define PIC16F_CODE_HIGH   (0x1fff)
#define PIC16F_CONFIG_LOW  (0x2000)
#define PIC16F_CONFIG_HIGH (0x20ff)
#define PIC16F_DATA_LOW    (0x2100)
#define PIC16F_DATA_HIGH   (0x21ff)

/* default timings until per datasheet */
#define PIC16F_TPROG_DEFAULT (10000)        /* 10ms */
#define PIC16F_TERASE_DEFAULT (10000)       /* 10ms */
#define PIC16F_TDISCHARGE_DEFAULT (1000)   /*  1ms */

/* FIXME hardware function prototypes */
#if 0
void            pic16f_begin_programming_(struct k8048 *);
void            pic16f_begin_programming_(struct k8048 *);
void            pic16f_end_programming_(struct k8048 *);
void            pic16f_end_programming_(struct k8048 *);
#endif
void            pic16f_load_configuration(struct k8048 *, unsigned short);
void            pic16f_load_data_for_program_memory(struct k8048 *, unsigned short);
void            pic16f_load_data_for_data_memory(struct k8048 *, unsigned short);
void            pic16f_increment_address(struct k8048 *);
unsigned short  pic16f_read_data_from_program_memory(struct k8048 *);
unsigned char   pic16f_read_data_from_data_memory(struct k8048 *);
void            pic16f_begin_erase_programming(struct k8048 *);
void            pic16f_chip_erase(struct k8048 *);
void            pic16f_bulk_erase_program_memory(struct k8048 *);
void            pic16f_bulk_erase_data_memory(struct k8048 *);
void            pic16f_bulk_erase_setup1(struct k8048 *);
void            pic16f_bulk_erase_setup2(struct k8048 *);

/* compound functions */
unsigned short pic16f_read_program_memory_increment(struct k8048 *);
unsigned char  pic16f_read_data_memory_increment(struct k8048 *);
void pic16f_read_config_memory(struct k8048 *);
unsigned short pic16f_read_osccal(struct k8048 *);
unsigned short pic16f_read_program_memory_block(struct k8048 *, unsigned short *, int);
unsigned short pic16f_read_data_memory_block(struct k8048 *, unsigned char *, int);
void pic16f_disableprotection(struct k8048 *, unsigned short osccal, unsigned short config);
void pic16f_bulkerase(struct k8048 *);
int pic16f_write_osccal(struct k8048 *, unsigned short);
int pic16f_write_config(struct k8048 *, unsigned short);

/* regions (code/config/data) */
int pic16f_getregion(unsigned int);
unsigned int pic16f_initregion(struct k8048 *, int);
void pic16f_loadregion(struct k8048 *, int, unsigned short);
int pic16f_verifyregion(struct k8048 *, unsigned short, unsigned short, int);

/* program/verify */
int pic16f_programregion(struct k8048 *, unsigned short, int, unsigned short);
void pic16f_program(struct k8048 *);
int pic16f_verify(struct k8048 *);

/* diagnostics */
void pic16f_dumpdeviceid(struct k8048 *);
void pic16f_dumposccal(struct k8048 *);
void pic16f_dumpconfig(struct k8048 *);
void pic16f_dumpconfig_16f627(unsigned int);
void pic16f_dumpconfig_12f675(unsigned int);
void pic16f_dumpconfig_16f877a(unsigned int);
void pic16f_dumpconfig_16f88(unsigned int, unsigned int);

#endif
